def es_vocal(c):
    '''
    c es una string que contiene un solo carácter en minúsculas.
    El resultado indica si c es una letra vocal. 

    >>> es_vocal('a')
    True
    >>> es_vocal('z')
    False
    '''
    return c in "aeiou"


def es_consonante(c):
    '''
    c es una string que contiene un solo carácter en minúsculas.
    El resultado indica si c es una letra consonante. 

    >>> es_consonante('z')
    True
    >>> es_consonante('3')
    False
    >>> es_consonante('e')
    False
    '''
    return c in "bcdfghjklmnpqrstvwyz"
    # También es correcto
    # return 'a' <= c <= 'z' and not es_vocal(c)


def es_letra(c):
    '''
    c es una string que contiene un solo carácter en minúsculas.
    El resultado indica si c es una letra. 

    >>> es_letra('e')
    True
    >>> es_letra('3')
    False
    >>> es_letra('?')
    False
    '''
    return c in "abcdefghijklmnopqrstuvwyz"    
    # También son correctos
    # return 'a' <= c <= 'z'
    # y 
    # return es_vocal(c) or es_consonante(c)

    
def es_digito(c):
    '''
    c es una string que contiene un solo carácter en minúsculas.
    El resultado indica si c es un dígito. 

    >>> es_digito('?')
    False
    >>> es_digito('8')
    True
    >>> es_digito('0')
    True
    >>> es_digito('r')
    False
    '''
    return '0' <= c <= '9'


def es_mayuscula(c):
    '''
    c es una string que contiene un solo carácter.
    El resultado indica si c es una letra mayúscula. 

    >>> es_mayuscula('3')
    False
    >>> es_mayuscula('R')
    True
    >>> es_mayuscula('Z')
    True
    >>> es_mayuscula('s')
    False
    '''
    return 'A' <= c <= 'Z'


def es_minuscula(c):
    '''
    c es una string que contiene un solo carácter.
    El resultado indica si c es una letra minúscula. 

    >>> es_minuscula('s')
    True
    >>> es_minuscula('A')
    False
    '''
    return 'a' <= c <= 'z'
   

def mayuscula_a_minuscula(c):
    '''
    c es una string que contiene un solo carácter que corresponde 
    a una letra mayúscula.
    El resultado es una letra igual que c en minúsculas.

    También se puede usar c.lower(). La operación lower sirve para strings con 
    más de un carácter, por ejemplo, "La Casa".lower()

    >>> mayuscula_a_minuscula('B')
    'b'
    '''
    distancia = ord('a') - ord('A')  # distancia de mayusculas a minusculas
    return chr(ord(c) + distancia)
 


def minuscula_a_mayuscula(c):
    '''
    c es una string que contiene un solo carácter que corresponde 
    a una letra minúscula.
    El resultado es una letra igual que c en mayúsculas.

    También se puede usar c.upper(). La operación lower sirve para strings con 
    más de un carácter, por ejemplo, "La Casa".upper()

    >>> minuscula_a_mayuscula('g')
    'G'
    '''
    distancia = ord('a') - ord('A')  # distancia de mayusculas a minusculas
    return chr(ord(c) - distancia)
    
    
    
def digito_a_entero(c):
    '''
    c es una string que contiene un solo carácter que corresponde a un dígito.
    El resultado es el número entero correspondiente a c. 

    >>> digito_a_entero('8')
    8
    '''
    return ord(c) - ord('0')
    # También es correcto
    # return int(c).
    # La operación int(<string>) permite convertir a enteros cadenas de
    # caracteres formadas por varios dígitos, por ejemplo,
    # int("123").


def entero_a_digito(d):
    '''
    d es un número entero de una sola cifra, es decir 0 <= d <= 9
    El resultado es una string formada por un solo carácter que representa d.

    >>> entero_a_digito(8)
    '8'
    '''
    return chr(ord('0') + d)
    # También es correcto
    # return str(d). 
    # La operación str(<int>) permite convertir en cadenas de caracteres
    # enteros con varias cifras, por ejemplo, str(123).
    


def string_a_num_entero(num_string):
    '''
    num_string es una cadena de caracteres que representa un número entero. 
    El resultado es el número entero que representa n.

    >>> string_a_num_entero("18")
    18
    '''
    return int(num_string)


def num_entero_a_string(num):
    '''
    num es un número entero que puede tener varias cifras. 
    El resultado es una string que representa num. 

    >>> num_entero_a_string(18)
    '18'
    '''
    return str(num)
 

if __name__ == '__main__':
    '''
    '''
    import doctest
    doctest.testmod()
